ARTHUR
======

A set of tools for building AARTFAAC visualisations.

Things like:

* A fast and simple imager
* Tools for streaming images to a rtsm server (youtube)
* Tools for visualising all kind of other meta data

requirements
------------

* Python 3, but python 2 mostly works.


Why ARTHUR?
-----------

because Arthur is the anthropomorphic AARTFAAC

Notes
-----

This repo uses git lfs. If you want to run the test suite
dont forget to unzip the tarball in `test/data`.


